#pragma once

#include <string>
#include <filesystem>
#include <vector>
#include <unordered_set>




namespace fs = std::filesystem;

class FileExplorer
{
public:
    // Shows the explorer window (call every frame)
    static void Show(bool* p_open = nullptr);
    static bool Init();

    static void Update();
    static void ProcessLoadQueue();



    static bool LoadingDone();

    static const std::vector<fs::path>& GetLoadQueue() { return s_loadQueue; }


    static std::string SelectedPath;

private:
    static bool s_initialized;

    // File browsing state
    static fs::path s_root;
    static fs::path s_currentDir;

    static std::unordered_set<std::string> s_knownFiles;  // <-- new


    // Icons
    static const char* ICONS_PATH;
    static unsigned int     s_folderIcon;

    // Filters & view state (unchanged)...
    static std::string fileSearchQuery;
    static bool sortAscending;
    static int  sortMode;
    static bool showScenes, showImages, showAudio, showScripts, showOther;

    // Asset loading queue
    static std::vector<fs::path> s_loadQueue;
    static size_t                s_loadIndex;
    static bool                  s_loadingInit;

    static std::string IconFileForPath(const fs::path &path);
    static void DrawFolderTree(const fs::path &path);

    // Initializes file queue by scanning res:// recursively
    static void InitLoading();
};


class ProjectManager
{
public:
    static bool Init();

    /// Load an existing project at projectPath/projectName.
    /// Reads the .cproj, sets current path/name, and ensures folders.
    static bool LoadProject(const std::string& projectFilePath);

    /// Save (or create) a project at projectPath/projectName.
    /// Writes the .cproj YAML, sets current path/name, and ensures folders.
    static bool SaveProject(const std::string& projectPath,
                            const std::string& projectName);

    // Creates a project at the path with the name
    // makes a .cproj file at the path in the name folder
    static bool CreateProject(const std::string& projectPath,
                            const std::string& projectName);

    static void ShowCreateProjectPopup();

    static bool HasProject();


    static const std::string& GetCurrentProjectPath();
    static const std::string& GetCurrentProjectName();
    static const std::string& GetCurrentAssetsPath();

    static std::string ResolveResPath(const std::string& resPath);



private:
    static std::string s_currentProjectPath;
    static std::string s_currentProjectName;
    static std::string s_defaultScene;

};
